@@ -1,12 +1,13 @@
 
 ##  digest -- hash digest functions for R
 ##
-##  Copyright (C) 2003 - 2024  Dirk Eddelbuettel <edd@debian.org>
+##  Copyright (C) 2003 - 2025  Dirk Eddelbuettel <edd@debian.org>
 ##  Copyright (C) 2009 - 2019  Henrik Bengtsson
 ##  Copyright (C) 2012 - 2019  Hannes Muehleisen
 ##  Copyright (C) 2014 - 2019  Jim Hester
 ##  Copyright (C) 2019         Kendon Bell
 ##  Copyright (C) 2019         Matthew de Queljoe
+##  Copyright (C) 2025         Bill Denney
 ##
 ##  This file is part of digest.
 ##
@@ -43,22 +44,21 @@ digest <- function(object, algo=c("md5", "sha1", "crc32", "sha256", "sha512",
                               "xxhash32", "xxhash64", "murmur32",
                               "spookyhash", "blake3", "crc32c",
                               "xxh3_64", "xxh3_128"))
-    errormode <- match.arg(errormode, c("stop", "warn", "silent"))
 
     if (is.infinite(length)) {
         length <- -1               # internally we use -1 for infinite len
     }
 
     if (is.character(file) && missing(object)) {
-        object <- file                  # nocov
-        file <- TRUE                  	# nocov
+        object <- file
+        file <- TRUE
     }
 
     is_streaming_algo <- algo == "spookyhash"
 
     if (is_streaming_algo && !serialize) {
-        .errorhandler(paste0(algo, " algorithm is not available without serialization."),  # #nocov
-                      mode=errormode)                                                      # #nocov
+        return(.errorhandler(paste0(algo, " algorithm is not available without serialization."),
+                             mode=errormode))
     }
 
     if (serialize && !file) {
@@ -79,8 +79,8 @@ digest <- function(object, algo=c("md5", "sha1", "crc32", "sha256", "sha512",
 
     } else if (!is.character(object) && !inherits(object,"raw") &&
                !is_streaming_algo) {
-        return(.errorhandler(paste("Argument object must be of type character",		    # #nocov
-                                   "or raw vector if serialize is FALSE"), mode=errormode)) # #nocov
+        return(.errorhandler(paste("Argument object must be of type character",
+                                   "or raw vector if serialize is FALSE"), mode=errormode))
     }
     if (file && !is.character(object))
         return(.errorhandler("file=TRUE can only be used with a character object",          # #nocov
@@ -97,7 +97,7 @@ digest <- function(object, algo=c("md5", "sha1", "crc32", "sha256", "sha512",
     if (file) {
         algoint <- algoint+100
         object <- path.expand(object)
-        if (.isWindows()) object <- enc2utf8(object)
+        if (.isWindows()) object <- enc2utf8(object)                                        # #nocov
         check_file(object, errormode)
     }
     ## if skip is auto (or any other text for that matter), we just turn it
@@ -129,6 +129,7 @@ digest <- function(object, algo=c("md5", "sha1", "crc32", "sha256", "sha512",
 ## utility functions used by digest() and  getVDigest() below
 
 .errorhandler <- function(txt, obj="", mode="stop") {
+    mode <- match.arg(mode, c("stop","warn","silent"))
     if (mode == "stop") {                                                                # nocov start
         stop(txt, obj, call.=FALSE)
     } else if (mode == "warn") {
